; $Id: cvtendian.pro,v 1.1 1998/05/04 19:34:06 rgr Exp $

; $RCSfile: cvtendian.pro,v $
; $Author: rgr $
; $Date: 1998/05/04 19:34:06 $
; $Revision: 1.1 $


; This procedure converts (if necessary) an ACE to the native endian
; of the machine on which the procedure is being run.  If the file
; is not recognized as an ACE file or is already in the native
; endian of the machine, the file is left unmodified.
;
; Arguments
;    filename = name of the file to be converted-(input)

pro cvtEndian, filename

   common AceSymbols

   ; Open the file to be converted.

   get_lun, lun
   openu, lun, filename, error=err
   if (err ne 0) then begin
      print, "Cannot open ", filename
      free_lun, lun
      return
   endif

   ; Get the size of the file and check that it is of sufficient size
   ; to contain a valid header record.

   header = {PrimaryHeader}
   lengthHeader = n_tags(header, /length)
   stat = fstat(lun)
   if (stat.size lt lengthHeader) then begin
      print, filename, " does not have a valid header."
      close, lun
      free_lun, lun
      return
   endif

   ; Read the header record and test whether the header record has the
   ; pattern for an ACE file.  If it does, then return without doing
   ; anything.  If not, then perform byte swaps on the header and
   ; test if the new header has the right pattern.  If not, then
   ; print an error message and return without modifying the file.

   rec = assoc(lun, header)
   header = rec[0]
   if (header.pattern eq G$_Ace.file.pattern) then begin
      print, filename, " is already the right endian."
      close, lun
      free_lun, lun
      return
   endif
   header = swap_endian(header)
   if (header.pattern ne G$_Ace.file.pattern) then begin
      print, filename, "does not have a valid header."
      close, lun
      free_lun, lun
      return
   endif

   ; Look at the format ID in the header to determine the type of
   ; structures in the file.  If the format ID is recognized, then
   ; set the variable struct to the type of data structure in the
   ; file.  If it is not recognized, then print an error message and
   ; return without modifying the file.


   type = G$_Ace.file   
   case header.FormatId of
      type.L1CrisSubset           : struct = {L1CrisSubset}
      type.L1CrisSummary          : struct = {L1CrisSummary}
      type.L1CrisCommandEcho      : struct = {L1CrisCommandEcho}
      type.L1CrisHskp             : struct = {L1CrisHskp}
      type.L1CrisLowPriorityRate  : struct = {L1CrisLowPriorityRate}
      type.L1CrisHighPriorityRate : struct = {L1CrisHighPriorityRate}
      type.L1CrisCommandTable     : struct = {L1CrisCommandTable}
      type.L1CrisEventCycle       : struct = {L1CrisEventCycle}
      type.L1CrisDiagnosticEvent  : struct = {L1CrisDiagnosticEvent}
      type.BrowseCris             : struct = {BrowseCris}

      type.L1SisSubset            : struct = {L1SisSubset}
      type.L1SisSummary           : struct = {L1SisSummary}
      type.L1SisCommandEcho       : struct = {L1SisCommandEcho}
      type.L1SisHskp              : struct = {L1SisHskp}
      type.L1SisLowPriorityRate   : struct = {L1SisLowPriorityRate}
      type.L1SisHighPriorityRate  : struct = {L1SisHighPriorityRate}
      type.L1SisCommandTable      : struct = {L1SisCommandTable}
      type.L1SisDacOffset0        : struct = {L1SisDacOffset0}
      type.L1SisDacOffset1        : struct = {L1SisDacOffset1}
      type.L1SisEventCycle        : struct = {L1SisEventCycle}
      type.L1SisDiagnosticEvent   : struct = {L1SisDiagnosticEvent}
      type.BrowseSis              : struct = {BrowseSis}

      else : begin
                print, filename, " has an unrecognized structure."
                close, lun
                free_lun, lun
                return
             end
   endcase

   ; Determine the length and number of structures in the file.

   lengthStruct = n_tags(struct, /length)
   nstruct = (stat.size - lengthHeader) / lengthStruct

   ; Set up the assoc to input/output all the data structures in a
   ; single operation.

   structs = replicate(struct, nstruct)
   record = assoc(lun, structs, lengthHeader)

   ; Write out the converted header record, read and convert all the
   ; data structures, and write the converted data structures back to
   ; the file.

   rec[0] = header
   structs = swap_endian(record[0])
   record[0] = structs

   ; Close the file and print out the conversion message.

   close, lun
   free_lun, lun
   print, filename, " has been converted."

end
