; $Id: buildsegmentdictionary.pro,v 1.1 1998/07/27 13:30:45 rgr Exp $

; $RCSfile: buildsegmentdictionary.pro,v $
; $Author: rgr $
; $Date: 1998/07/27 13:30:45 $
; $Revision: 1.1 $


; This procedure builds the segment dictionary from the information
; contained in the template file.  Each segment in the dictionary is
; defined by the four fields:  name, variable, format, and compressed
; name.
;
; The template file that defines the dictionary contains one line
; for each entry to be put into the dictionary.  That line contains
; the name, variable, and format fields enclosed within the
; segment delimiters.  The compressed name field is derived from
; the name field by replacing any macro placeholders in the name
; field with blanks and then removing all blanks from the name.
;
;
;  Arguments
;     line = lines from the template that define the dictionary-(input)
;     segmentDelimiter = segment delimiters used in the template-(input)
;     macroDelimiter = macro delimiters used in the segments-(input)
;     dictName = full name of each dictionary entry-(output)
;     dictVariable = segment variables of each dictionary entry-(output)
;     dictFormat = format field of each dictionary entry-(output)
;     dictNameCompressed = compressed name of each dictionary
;                          entry-(output)
;
;
;  Procedures and functions used
;     compressDumpSegment


pro buildSegmentDictionary, line,              $
                            segmentDelimiter,  $
                            macroDelimiter,    $
                            dictName,          $
                            dictVariable,      $
                            dictFormat,        $
                            dictNameCompressed

   blankArray = bytarr(256, /nozero)
   blankArray[*] = '20'XB
   blankString = string(blankArray)

   nline = n_elements(line)
   dictName = strarr(nline)
   dictVariable = strarr(nline)
   dictFormat = strarr(nline)
   dictNameCompressed = strarr(nline)

   for i=0, nline-1 do begin
      mark0 = strpos(line[i], segmentDelimiter[0], 0)
      mark1 = strpos(line[i], segmentDelimiter[1], mark0)
      dictName[i] = strmid(line[i], mark0+1, (mark1 - mark0) - 1)
      dictNameCompressed[i] =                                         $
                      compressDumpSegment(dictName[i], macroDelimiter)
      mark0 = strpos(line[i], segmentDelimiter[0], mark1)
      mark1 = strpos(line[i], segmentDelimiter[1], mark0)
      dictVariable[i] = strmid(line[i], mark0+1, (mark1 - mark0) - 1)
      mark0 = strpos(line[i], segmentDelimiter[0], mark1)
      mark1 = strpos(line[i], segmentDelimiter[1], mark0)
      dictFormat[i] = strmid(line[i], mark0+1, (mark1 - mark0) - 1)
   endfor

end
