; $Id: gendumpline.pro,v 1.1 1998/07/27 13:30:51 rgr Exp $

; $RCSfile: gendumpline.pro,v $
; $Author: rgr $
; $Date: 1998/07/27 13:30:51 $
; $Revision: 1.1 $

; This procedure generates the IDL code to write one line of the dump.
; The basic procedure that is used is
;
;    1. generate code to store the template for the line in the
;       variable line,
;    2. for each segment located in the template, 
;       a. locate the appropriate dictionary entry,
;       b. generate code to put blanks into variable line where the
;          segment is acting as a placeholder,
;       c. generate the code that stores the replacement value of the
;          segment in the variable segmentVariable,
;       d. generate the code that stores segmentVariable in the
;          variable line,
;       e. generate code to print the variable line.
;       
;
;  Arguments
;     lun = logical unit of the file to contain the procedure-(input)
;     index = index of the template line being expanded-(input)
;     template = template of the line for which code is being
;                generated-(input)
;     segmentDelimiters = delimiters for segments embedded in the 
;                         template-(input)
;     macroDelimiter = delimiters for macro values embedded in the
;                      segments-(input)
;     macroSymbol = symbol for macros in dictionary variables-(input)
;     dictName = full dictionary names of segments-(input)
;     dictVariables = dictionary variables for segments-(input)
;     dictFormat = dictionary formats for segments-(input)
;     dictNameCompressed = compressed dictionary names of
;                          segments-(input)
;
;
;  Procedures and Functions used
;     CFormatToIdlFormat
;     compressDumpSegment
;     expandSegmentVariables


pro genDumpLine, lun,               $
                 index,             $
                 template,          $
                 segmentDelimiter,  $
                 macroDelimiter,    $
                 macroSymbol,       $
                 dictName,          $
                 dictVariable,      $
                 dictFormat,        $
                 dictNameCompressed

   blankArray = bytarr(256, /nozero)
   blankArray[*] = '20'XB
   blankString = string(blankArray)

   number = strcompress(string(index), /remove_all)
   printf, lun, "   line = template[" + number + "]"
   line = template
   mark0 = strpos(line, segmentDelimiter[0])
   while (mark0 ge 0) do begin
      mark1 = strpos(line, segmentDelimiter[1], mark0)
      segment = strmid(line, mark0 +1, (mark1 - mark0) - 1)
      seg = compressDumpSegment(segment, macroDelimiter)
      lookup = where(seg eq dictNameCompressed, nlookup)
      if (nlookup ne 1) then                                  $
         stop, seg, " - Cannot locate unique dictionary name"
      lookup = lookup[0]
      blanks = strmid(blankString, mark0, (mark1-mark0) + 1)
      pos = strcompress(string(mark0), /remove_all)
      printf, lun, '      strput, line, "' + blanks + '", ' + pos
      variable = expandSegmentVariables(segment, dictName[lookup],    $
                                        dictVariable[lookup],         $
                                        macroDelimiter, macroSymbol)
      idlFormat = CFormatToIdlFormat(dictFormat[lookup])
      printf, lun, "      segmentValue = string(" + variable + ", "   $
                                       + 'FORMAT="' + idlFormat + '")'
      printf, lun, "      strput, line, segmentValue, " + pos
      mark0 = strpos(line, segmentDelimiter[0], mark1)
   endwhile
   printf, lun, "      printf, lunit, line"

end
