; $Id: get_group_hskps_ce.pro,v 1.1 1998/05/04 19:53:42 rgr Exp $

; $RCSfile: get_group_hskps_ce.pro,v $
; $Author: rgr $
; $Date: 1998/05/04 19:53:42 $
; $Revision: 1.1 $

; This function generates and returns the L1_1CrisHskp structures
; between a start and stop time.  The function uses the information in
; the L1CrisHskp structurea and calibration information embedded in
; the conversion routines.
;
; Arguments
;    sec0_1996 - start time in seconds of 1996-(input)
;    sec1_1996 - stop time in seconds of 1996-(input)
;
;
; Procedures and functions used
;    cvtCrisAdcToDegC
;    cvtCrisAdcToLeakageCurrent
;    cvtCrisAdcToMonitorValue
;    cvtCrisDacToControlVoltage
;    get_group_hskps_c

function get_group_hskps_ce, sec0_1996, sec1_1996

   common CrisSymbols

   hskp = get_group_hskps_c(sec0_1996, sec1_1996)
   nrec = n_elements(hskp)
   engr = replicate({L1_1CrisHskp}, nrec)

   engr.ClockCycle = hskp.ClockCycle
   engr.Second1996 = hskp.Second1996
   engr.microsecond = hskp.microsecond

   ; Convert the ADC's for monitor voltages and currents.

   engr.MonitorP5V =                                                  $
     cvtCrisAdcToMonitorValue(G$_Cris.adc.MonitorP5V, hskp.MonitorP5V)
   engr.MonitorP6V =                                                  $
     cvtCrisAdcToMonitorValue(G$_Cris.adc.MonitorP6V, hskp.MonitorP6V)
   engr.MonitorM6V =                                                  $
     cvtCrisAdcToMonitorValue(G$_Cris.adc.MonitorM6V, hskp.MonitorM6V)
   engr.MonitorP7V =                                                  $
     cvtCrisAdcToMonitorValue(G$_Cris.adc.MonitorP7V, hskp.MonitorP7V)
   engr.MonitorM7V =                                                  $
     cvtCrisAdcToMonitorValue(G$_Cris.adc.MonitorM7V, hskp.MonitorM7V)
   engr.MonitorP12V =                                                  $
     cvtCrisAdcToMonitorValue(G$_Cris.adc.MonitorP12V, hskp.MonitorP12V)
   engr.MonitorM12V =                                                  $
     cvtCrisAdcToMonitorValue(G$_Cris.adc.MonitorM12V, hskp.MonitorM12V)
   engr.MonitorP13V =                                                  $
     cvtCrisAdcToMonitorValue(G$_Cris.adc.MonitorP13V, hskp.MonitorP13V)
   engr.MonitorM13V =                                                  $
     cvtCrisAdcToMonitorValue(G$_Cris.adc.MonitorM13V, hskp.MonitorM13V)
   engr.MonitorP15V =                                                  $
     cvtCrisAdcToMonitorValue(G$_Cris.adc.MonitorP15V, hskp.MonitorP15V)
   engr.MonitorP19V =                                                 $
     cvtCrisAdcToMonitorValue(G$_Cris.adc.MonitorP19V, hskp.MonitorP19V)
   engr.MonitorMcp1 =                                                  $
     cvtCrisAdcToMonitorValue(G$_Cris.adc.MonitorMcp1, hskp.MonitorMcp1)
   engr.MonitorMcp2 =                                                 $
     cvtCrisAdcToMonitorValue(G$_Cris.adc.MonitorMcp2, hskp.MonitorMcp2)
   engr.MonitorHvps1I =                                               $
                  cvtCrisAdcToMonitorValue(G$_Cris.adc.MonitorHvps1I, $
                                                   hskp.MonitorHvps1I)
   engr.MonitorHvps2I =                                               $
                  cvtCrisAdcToMonitorValue(G$_Cris.adc.MonitorHvps2I, $
                                                   hskp.MonitorHvps2I)
   engr.MonitorHvps3I =                                               $
                  cvtCrisAdcToMonitorValue(G$_Cris.adc.MonitorHvps3I, $
                                                   hskp.MonitorHvps3I)
   engr.MonitorHvps4I =                                               $
                  cvtCrisAdcToMonitorValue(G$_Cris.adc.MonitorHvps4I, $
                                                   hskp.MonitorHvps4I)
   engr.MonitorSoftPsaI =                                             $
                cvtCrisAdcToMonitorValue(G$_Cris.adc.MonitorSoftPsaI, $
                                                 hskp.MonitorSoftPsaI)
   engr.MonitorSoftPsbI =                                             $
               cvtCrisAdcToMonitorValue(G$_Cris.adc.MonitorSoftPsbI,  $
                                                 hskp.MonitorSoftPsbI)

   ; Convert the ADC's for the temperatures.

   engr.TemperatureMotherBoardElect =                                 $
                    cvtCrisAdcToDegC(hskp.TemperatureMotherBoardElect)
   engr.TemperatureMotherBoardDet =                                   $
                      cvtCrisAdcToDegC(hskp.TemperatureMotherBoardDet)
   engr.TemperatureMotherBoardC =                                     $
                      cvtCrisAdcToDegC(hskp.TemperatureMotherBoardC)
   engr.TemperatureAnalogBoard =                                      $
                         cvtCrisAdcToDegC(hskp.TemperatureAnalogBoard)
   engr.TemperaturePostRegBoard =                                     $
                        cvtCrisAdcToDegC(hskp.TemperaturePostRegBoard)
   engr.TemperatureLogicBoard =                                       $
                          cvtCrisAdcToDegC(hskp.TemperatureLogicBoard)
   engr.TemperatureE12Elect =                                         $
                            cvtCrisAdcToDegC(hskp.TemperatureE12Elect)
   engr.TemperatureE12Det =  cvtCrisAdcToDegC(hskp.TemperatureE12Det)
   engr.TemperatureE34Elect =                                         $
                            cvtCrisAdcToDegC(hskp.TemperatureE34Elect)
   engr.TemperatureE34Det =  cvtCrisAdcToDegC(hskp.TemperatureE34Det)
   engr.TemperatureE56Elect =                                         $
                            cvtCrisAdcToDegC(hskp.TemperatureE56Elect)
   engr.TemperatureE56Det =  cvtCrisAdcToDegC(hskp.TemperatureE56Det)
   engr.TemperatureE789Elect =                                        $
                           cvtCrisAdcToDegC(hskp.TemperatureE789Elect)
   engr.TemperatureE789Det =  cvtCrisAdcToDegC(hskp.TemperatureE789Det)
   engr.TemperatureLvps = cvtCrisAdcToDegC(hskp.TemperatureLvps)
   engr.TemperatureHvps = cvtCrisAdcToDegC(hskp.TemperatureHvps)
   engr.TemperatureFiberPlaneTop0 =                                   $
                      cvtCrisAdcToDegC(hskp.TemperatureFiberPlaneTop0)
   engr.TemperatureFiberPlaneTop1 =                                   $
                      cvtCrisAdcToDegC(hskp.TemperatureFiberPlaneTop1)
   engr.TemperatureFiberPlaneMid =                                    $
                       cvtCrisAdcToDegC(hskp.TemperatureFiberPlaneMid)
   engr.TemperatureFiberPlaneBot =                                    $
                       cvtCrisAdcToDegC(hskp.TemperatureFiberPlaneBot)
   engr.TemperatureImageInt1Side =                                    $
                       cvtCrisAdcToDegC(hskp.TemperatureImageInt1Side)
   engr.TemperatureImageInt1Rear =                                    $
                       cvtCrisAdcToDegC(hskp.TemperatureImageInt1Rear)
   engr.TemperatureCamera1Elect =                                     $
                        cvtCrisAdcToDegC(hskp.TemperatureCamera1Elect)
   engr.TemperatureHvps1 = cvtCrisAdcToDegC(hskp.TemperatureHvps1)
   engr.TemperatureImageInt2Side =                                    $
                       cvtCrisAdcToDegC(hskp.TemperatureImageInt2Side)
   engr.TemperatureImageInt2Rear =                                    $
                       cvtCrisAdcToDegC(hskp.TemperatureImageInt2Rear)
   engr.TemperatureCamera2Elect =                                     $
                        cvtCrisAdcToDegC(hskp.TemperatureCamera2Elect)
   engr.TemperatureHvps2 = cvtCrisAdcToDegC(hskp.TemperatureHvps2)

   ; Convert the ADC's for the leakage currents.

   engr.LeakageCurrentE1a =                                            $
       cvtCrisAdcToLeakageCurrent(G$_Cris.adc.PostDcE1a, hskp.PostDcE1a)
   engr.LeakageCurrentE1b =                                            $
       cvtCrisAdcToLeakageCurrent(G$_Cris.adc.PostDcE1b, hskp.PostDcE1b)
   engr.LeakageCurrentE2ab =                                           $
     cvtCrisAdcToLeakageCurrent(G$_Cris.adc.PostDcE2ab, hskp.PostDcE2ab)
   engr.LeakageCurrentE3ab =                                           $
     cvtCrisAdcToLeakageCurrent(G$_Cris.adc.PostDcE3ab, hskp.PostDcE3ab)
   engr.LeakageCurrentE4ab =                                           $
     cvtCrisAdcToLeakageCurrent(G$_Cris.adc.PostDcE4ab, hskp.PostDcE4ab)
   engr.LeakageCurrentE5ab =                                           $
     cvtCrisAdcToLeakageCurrent(G$_Cris.adc.PostDcE5ab, hskp.PostDcE5ab)
   engr.LeakageCurrentE6ab =                                           $
     cvtCrisAdcToLeakageCurrent(G$_Cris.adc.PostDcE6ab, hskp.PostDcE6ab)
   engr.LeakageCurrentE7ab =                                           $
     cvtCrisAdcToLeakageCurrent(G$_Cris.adc.PostDcE7ab, hskp.PostDcE7ab)
   engr.LeakageCurrentE8ab =                                           $
     cvtCrisAdcToLeakageCurrent(G$_Cris.adc.PostDcE8ab, hskp.PostDcE8ab)
   engr.LeakageCurrentE9ab =                                           $
              cvtCrisAdcToLeakageCurrent(G$_Cris.adc.PostDcE9ab,       $
                                         hskp.PostDcE9ab, hskp.DacE9ab)
   engr.LeakageCurrentG2ab =                                           $
              cvtCrisAdcToLeakageCurrent(G$_Cris.adc.PostDcG2ab,       $
                                         hskp.PostDcG2ab, hskp.DacG2ab)
   engr.LeakageCurrentG3ab =                                           $
              cvtCrisAdcToLeakageCurrent(G$_Cris.adc.PostDcG3ab,       $
                                         hskp.PostDcG3ab, hskp.DacG3ab)
   engr.LeakageCurrentG4ab =                                           $
              cvtCrisAdcToLeakageCurrent(G$_Cris.adc.PostDcG4ab,       $
                                         hskp.PostDcG4ab, hskp.DacG4ab)
   engr.LeakageCurrentG5ab =                                           $
              cvtCrisAdcToLeakageCurrent(G$_Cris.adc.PostDcG5ab,       $
                                         hskp.PostDcG5ab, hskp.DacG5ab)
   engr.LeakageCurrentG6ab =                                           $
              cvtCrisAdcToLeakageCurrent(G$_Cris.adc.PostDcG6ab,       $
                                         hskp.PostDcG6ab, hskp.DacG6ab)
   engr.LeakageCurrentG7ab =                                           $
              cvtCrisAdcToLeakageCurrent(G$_Cris.adc.PostDcG7ab,       $
                                         hskp.PostDcG7ab, hskp.DacG7ab)
   engr.LeakageCurrentE1c =                                            $
       cvtCrisAdcToLeakageCurrent(G$_Cris.adc.PostDcE1c, hskp.PostDcE1c)
   engr.LeakageCurrentE1d =                                            $
       cvtCrisAdcToLeakageCurrent(G$_Cris.adc.PostDcE1d, hskp.PostDcE1d)
   engr.LeakageCurrentE2cd =                                           $
     cvtCrisAdcToLeakageCurrent(G$_Cris.adc.PostDcE2cd, hskp.PostDcE2cd)
   engr.LeakageCurrentE3cd =                                           $
     cvtCrisAdcToLeakageCurrent(G$_Cris.adc.PostDcE3cd, hskp.PostDcE3cd)
   engr.LeakageCurrentE4cd =                                           $
     cvtCrisAdcToLeakageCurrent(G$_Cris.adc.PostDcE4cd, hskp.PostDcE4cd)
   engr.LeakageCurrentE5cd =                                           $
     cvtCrisAdcToLeakageCurrent(G$_Cris.adc.PostDcE5cd, hskp.PostDcE5cd)
   engr.LeakageCurrentE6cd =                                           $
     cvtCrisAdcToLeakageCurrent(G$_Cris.adc.PostDcE6cd, hskp.PostDcE6cd)
   engr.LeakageCurrentE7cd =                                           $
     cvtCrisAdcToLeakageCurrent(G$_Cris.adc.PostDcE7cd, hskp.PostDcE7cd)
   engr.LeakageCurrentE8cd =                                           $
     cvtCrisAdcToLeakageCurrent(G$_Cris.adc.PostDcE8cd, hskp.PostDcE8cd)
   engr.LeakageCurrentE9cd =                                           $
              cvtCrisAdcToLeakageCurrent(G$_Cris.adc.PostDcE9cd,       $
                                         hskp.PostDcE9cd, hskp.DacE9cd)
   engr.LeakageCurrentG2cd =                                           $
              cvtCrisAdcToLeakageCurrent(G$_Cris.adc.PostDcG2cd,       $
                                         hskp.PostDcG2cd, hskp.DacG2cd)
   engr.LeakageCurrentG3cd =                                           $
              cvtCrisAdcToLeakageCurrent(G$_Cris.adc.PostDcG3cd,       $
                                         hskp.PostDcG3cd, hskp.DacG3cd)
   engr.LeakageCurrentG4cd =                                           $
              cvtCrisAdcToLeakageCurrent(G$_Cris.adc.PostDcG4cd,       $
                                         hskp.PostDcG4cd, hskp.DacG4cd)
   engr.LeakageCurrentG5cd =                                           $
              cvtCrisAdcToLeakageCurrent(G$_Cris.adc.PostDcG5cd,       $
                                         hskp.PostDcG5cd, hskp.DacG5cd)
   engr.LeakageCurrentG6cd =                                           $
              cvtCrisAdcToLeakageCurrent(G$_Cris.adc.PostDcG6cd,       $
                                         hskp.PostDcG6cd, hskp.DacG6cd)
   engr.LeakageCurrentG7cd =                                           $
              cvtCrisAdcToLeakageCurrent(G$_Cris.adc.PostDcG7cd,       $
                                         hskp.PostDcG7cd, hskp.DacG7cd)

   ; Convert the DAC's for control voltage.

   engr.DacG2ab = cvtCrisDacToControlVoltage(hskp.DacG2ab)
   engr.DacG3ab = cvtCrisDacToControlVoltage(hskp.DacG3ab)
   engr.DacG4ab = cvtCrisDacToControlVoltage(hskp.DacG4ab)
   engr.DacG5ab = cvtCrisDacToControlVoltage(hskp.DacG5ab)
   engr.DacG6ab = cvtCrisDacToControlVoltage(hskp.DacG6ab)
   engr.DacG7ab = cvtCrisDacToControlVoltage(hskp.DacG7ab)
   engr.DacE9ab = cvtCrisDacToControlVoltage(hskp.DacE9ab)
   engr.DacG2cd = cvtCrisDacToControlVoltage(hskp.DacG2cd)
   engr.DacG3cd = cvtCrisDacToControlVoltage(hskp.DacG3cd)
   engr.DacG4cd = cvtCrisDacToControlVoltage(hskp.DacG4cd)
   engr.DacG5cd = cvtCrisDacToControlVoltage(hskp.DacG5cd)
   engr.DacG6cd = cvtCrisDacToControlVoltage(hskp.DacG6cd)
   engr.DacG7cd = cvtCrisDacToControlVoltage(hskp.DacG7cd)
   engr.DacE9cd = cvtCrisDacToControlVoltage(hskp.DacE9cd)

   ; Generate the quality flags

   engr.QualityMonitorP5V = hskp.QualityMonitorP5V
   engr.QualityMonitorP6V = hskp.QualityMonitorP6V
   engr.QualityMonitorM6V = hskp.QualityMonitorM6V
   engr.QualityMonitorP7V = hskp.QualityMonitorP7V
   engr.QualityMonitorM7V = hskp.QualityMonitorM7V
   engr.QualityMonitorP12V = hskp.QualityMonitorP12V
   engr.QualityMonitorM12V = hskp.QualityMonitorM12V
   engr.QualityMonitorP13V = hskp.QualityMonitorP13V
   engr.QualityMonitorM13V = hskp.QualityMonitorM13V
   engr.QualityMonitorP15V = hskp.QualityMonitorP15V
   engr.QualityMonitorP19V = hskp.QualityMonitorP19V
   engr.QualityMonitorMcp1 = hskp.QualityMonitorMcp1
   engr.QualityMonitorMcp2 = hskp.QualityMonitorMcp2
   engr.QualityMonitorHvps1I = hskp.QualityMonitorHvps1I
   engr.QualityMonitorHvps2I = hskp.QualityMonitorHvps2I
   engr.QualityMonitorHvps3I = hskp.QualityMonitorHvps3I
   engr.QualityMonitorHvps4I = hskp.QualityMonitorHvps4I
   engr.QualityMonitorSoftPsaI = hskp.QualityMonitorSoftPsaI
   engr.QualityMonitorSoftPsbI = hskp.QualityMonitorSoftPsbI
   engr.QualityTemperatureMotherBoardElect =                          $
                               hskp.QualityTemperatureMotherBoardElect
   engr.QualityTemperatureMotherBoardDet =                            $
                                 hskp.QualityTemperatureMotherBoardDet
   engr.QualityTemperatureMotherBoardC =                              $
                                   hskp.QualityTemperatureMotherBoardC
   engr.QualityTemperatureAnalogBoard =                               $
                                    hskp.QualityTemperatureAnalogBoard
   engr.QualityTemperaturePostRegBoard =                              $
                                   hskp.QualityTemperaturePostRegBoard
   engr.QualityTemperatureLogicBoard =                                $
                                     hskp.QualityTemperatureLogicBoard
   engr.QualityTemperatureE12Elect = hskp.QualityTemperatureE12Elect
   engr.QualityTemperatureE12Det = hskp.QualityTemperatureE12Det
   engr.QualityTemperatureE34Elect = hskp.QualityTemperatureE34Elect
   engr.QualityTemperatureE34Det = hskp.QualityTemperatureE34Det
   engr.QualityTemperatureE56Elect = hskp.QualityTemperatureE56Elect
   engr.QualityTemperatureE56Det = hskp.QualityTemperatureE56Det
   engr.QualityTemperatureE789Elect = hskp.QualityTemperatureE789Elect
   engr.QualityTemperatureE789Det = hskp.QualityTemperatureE789Det
   engr.QualityTemperatureLvps = hskp.QualityTemperatureLvps
   engr.QualityTemperatureHvps = hskp.QualityTemperatureHvps
   engr.QualityTemperatureFiberPlaneTop0 =                            $
                                 hskp.QualityTemperatureFiberPlaneTop0
   engr.QualityTemperatureFiberPlaneTop1 =                            $
                                 hskp.QualityTemperatureFiberPlaneTop1
   engr.QualityTemperatureFiberPlaneMid =                             $
                                  hskp.QualityTemperatureFiberPlaneMid
   engr.QualityTemperatureFiberPlaneBot =                             $
                                  hskp.QualityTemperatureFiberPlaneBot
   engr.QualityTemperatureImageInt1Side =                             $
                                  hskp.QualityTemperatureImageInt1Side
   engr.QualityTemperatureImageInt1Rear =                             $
                                  hskp.QualityTemperatureImageInt1Rear
   engr.QualityTemperatureCamera1Elect =                              $
                                   hskp.QualityTemperatureCamera1Elect
   engr.QualityTemperatureHvps1 = hskp.QualityTemperatureHvps1
   engr.QualityTemperatureImageInt2Side =                             $
                                  hskp.QualityTemperatureImageInt2Side
   engr.QualityTemperatureImageInt2Rear =                             $
                                  hskp.QualityTemperatureImageInt2Rear
   engr.QualityTemperatureCamera2Elect =                              $
                                   hskp.QualityTemperatureCamera2Elect
   engr.QualityTemperatureHvps2 = hskp.QualityTemperatureHvps2
   engr.QualityLeakageCurrentE1a = hskp.QualityPostDcE1a
   engr.QualityLeakageCurrentE1b = hskp.QualityPostDcE1b
   engr.QualityLeakageCurrentE2ab = hskp.QualityPostDcE2ab
   engr.QualityLeakageCurrentE3ab = hskp.QualityPostDcE3ab
   engr.QualityLeakageCurrentE4ab = hskp.QualityPostDcE4ab
   engr.QualityLeakageCurrentE5ab = hskp.QualityPostDcE5ab
   engr.QualityLeakageCurrentE6ab = hskp.QualityPostDcE6ab
   engr.QualityLeakageCurrentE7ab = hskp.QualityPostDcE7ab
   engr.QualityLeakageCurrentE8ab = hskp.QualityPostDcE8ab
   engr.QualityLeakageCurrentE9ab =                                   $
                         hskp.QualityPostDcE9ab or hskp.QualityDacE9ab
   engr.QualityLeakageCurrentG2ab =                                   $
                         hskp.QualityPostDcG2ab or hskp.QualityDacG2ab
   engr.QualityLeakageCurrentG3ab =                                   $
                         hskp.QualityPostDcG3ab or hskp.QualityDacG3ab
   engr.QualityLeakageCurrentG4ab =                                   $
                         hskp.QualityPostDcG4ab or hskp.QualityDacG4ab
   engr.QualityLeakageCurrentG5ab =                                   $
                         hskp.QualityPostDcG5ab or hskp.QualityDacG5ab
   engr.QualityLeakageCurrentG6ab =                                   $ 
                         hskp.QualityPostDcG6ab or hskp.QualityDacG6ab
   engr.QualityLeakageCurrentG7ab =                                   $
                         hskp.QualityPostDcG7ab or hskp.QualityDacG7ab
   engr.QualityLeakageCurrentE1c = hskp.QualityPostDcE1c
   engr.QualityLeakageCurrentE1d = hskp.QualityPostDcE1d
   engr.QualityLeakageCurrentE2cd = hskp.QualityPostDcE2cd
   engr.QualityLeakageCurrentE3cd = hskp.QualityPostDcE3cd
   engr.QualityLeakageCurrentE4cd = hskp.QualityPostDcE4cd
   engr.QualityLeakageCurrentE5cd = hskp.QualityPostDcE5cd
   engr.QualityLeakageCurrentE6cd = hskp.QualityPostDcE6cd
   engr.QualityLeakageCurrentE7cd = hskp.QualityPostDcE7cd
   engr.QualityLeakageCurrentE8cd = hskp.QualityPostDcE8cd
   engr.QualityLeakageCurrentE9cd =                                   $
                         hskp.QualityPostDcE9cd or hskp.QualityDacE9cd
   engr.QualityLeakageCurrentG2cd =                                   $
                         hskp.QualityPostDcG2cd or hskp.QualityDacG2cd
   engr.QualityLeakageCurrentG3cd =                                   $
                         hskp.QualityPostDcG3cd or hskp.QualityDacG3cd
   engr.QualityLeakageCurrentG4cd =                                   $
                         hskp.QualityPostDcG4cd or hskp.QualityDacG4cd
   engr.QualityLeakageCurrentG5cd =                                   $
                         hskp.QualityPostDcG5cd or hskp.QualityDacG5cd
   engr.QualityLeakageCurrentG6cd =                                   $ 
                         hskp.QualityPostDcG6cd or hskp.QualityDacG6cd
   engr.QualityLeakageCurrentG7cd =                                   $
                         hskp.QualityPostDcG7cd or hskp.QualityDacG7cd
   engr.QualityDacG2ab = hskp.QualityDacG2ab
   engr.QualityDacG3ab = hskp.QualityDacG3ab
   engr.QualityDacG4ab = hskp.QualityDacG4ab
   engr.QualityDacG5ab = hskp.QualityDacG5ab
   engr.QualityDacG6ab = hskp.QualityDacG6ab
   engr.QualityDacG7ab = hskp.QualityDacG7ab
   engr.QualityDacE9ab = hskp.QualityDacE9ab
   engr.QualityDacG2cd = hskp.QualityDacG2cd
   engr.QualityDacG3cd = hskp.QualityDacG3cd
   engr.QualityDacG4cd = hskp.QualityDacG4cd
   engr.QualityDacG5cd = hskp.QualityDacG5cd
   engr.QualityDacG6cd = hskp.QualityDacG6cd
   engr.QualityDacG7cd = hskp.QualityDacG7cd
   engr.QualityDacE9cd = hskp.QualityDacE9cd

   return, engr
end
