; $Id: get_group_summaries_ce.pro,v 1.2 1998/07/27 13:58:46 rgr Exp $

; $RCSfile: get_group_summaries_ce.pro,v $
; $Author: rgr $
; $Date: 1998/07/27 13:58:46 $
; $Revision: 1.2 $

; This function generates and returns the L1_1CrisSummary structures
; between a start and stop time.
;
; Arguments
;    sec0_1996 - start time in seconds of 1996-(input)
;    sec1_1996 - stop time in seconds of 1996-(input)
;
;
; Procedures and functions used
;    get_group_summaries_c

function get_group_summaries_ce, sec0_1996, sec1_1996

   sum = get_group_summaries_c(sec0_1996, sec1_1996)
   nrec = n_elements(sum)
   engr = replicate({L1_1CrisSummary}, nrec)

   engr.ClockMinorFrame = sum.ClockMinorFrame
   engr.Second1996 = sum.Second1996
   engr.microsecond = sum.microsecond
   engr.FormatId = sum.FormatId
   engr.MajorFrameCount = sum.MajorFrameCount
   engr.MinorFrameCount = sum.MinorFrameCount
   engr.quality = sum.quality

   ; Convert the ADC's for voltage, currents, and temperatures.

   engr.MainBusVoltage = float(0.15054D * double(sum.MainBusVoltage))
   index = where(sum.MainBusVoltage eq 255B, nindex)
   if (nindex gt 0) then begin
      if (nindex eq 1) then index = index[0]
      engr[index].MainBusVoltage = !values.F_NaN
   endif
   engr.CrisCurrent = float(0.005602D * double(sum.CrisCurrent))
   index = where(sum.CrisCurrent eq 255B, nindex)
   if (nindex gt 0) then begin
      if (nindex eq 1) then index = index[0]
      engr[index].CrisCurrent = !values.F_NaN
   endif
   engr.CrisInternalTemperature1 =                                    $
      float(-0.62745D * double(sum.CrisInternalTemperature1) + 100.0D) 
   index = where(sum.CrisInternalTemperature1 eq 255B, nindex)
   if (nindex gt 0) then begin
      if (nindex eq 1) then index = index[0]
      engr[index].CrisInternalTemperature1 = !values.F_NaN
   endif
   engr.CrisInternalTemperature2 =                                    $
      float(-0.62745D * double(sum.CrisInternalTemperature2) + 100.0D) 
   index = where(sum.CrisInternalTemperature2 eq 255B, nindex)
   if (nindex gt 0) then begin
      if (nindex eq 1) then index = index[0]
      engr[index].CrisInternalTemperature2 = !values.F_NaN
   endif
   engr.CrisInterfaceTemperature =                                    $
      float(-0.62745D * double(sum.CrisInterfaceTemperature) + 100.0D) 
   index = where(sum.CrisInterfaceTemperature eq 255B, nindex)
   if (nindex gt 0) then begin
      if (nindex eq 1) then index = index[0]
      engr[index].CrisInterfaceTemperature = !values.F_NaN
   endif

   engr.CrisHskp = sum.CrisHskp

   return, engr
end
