; $Id: get_group_hskps_se.pro,v 1.2 1998/07/27 14:31:19 rgr Exp $

; $RCSfile: get_group_hskps_se.pro,v $
; $Author: rgr $
; $Date: 1998/07/27 14:31:19 $
; $Revision: 1.2 $

; This function generates and returns the L1_1SisHskp structures
; between a start and stop time.  The function uses the information in
; the L1SisHskp structurea and calibration information embedded in
; the conversion routines.
;
; Arguments
;    sec0_1996 - start time in seconds of 1996-(input)
;    sec1_1996 - stop time in seconds of 1996-(input)
;
;
; Procedures and functions used
;    cvtSisAdcToDegC
;    cvtSisAdcToLeakageCurrent
;    cvtSisAdcToMonitorValue
;    get_group_hskps_s

function get_group_hskps_se, sec0_1996, sec1_1996

   common SisSymbols

   hskp = get_group_hskps_s(sec0_1996, sec1_1996)
   nrec = n_elements(hskp)
   engr = replicate({L1_1SisHskp}, nrec)

   engr.ClockCycle = hskp.ClockCycle
   engr.Second1996 = hskp.Second1996
   engr.microsecond = hskp.microsecond
   engr.CycleNumber = hskp.CycleNumber

   ; Convert the ADC's for monitor voltages and currents.

   engr.MonitorP4V =                                                  $
       cvtSisAdcToMonitorValue(G$_Sis.adc.MonitorP4V, hskp.MonitorP4V)
   engr.MonitorP5V =                                                  $
       cvtSisAdcToMonitorValue(G$_Sis.adc.MonitorP5V, hskp.MonitorP5V)
   engr.MonitorP7V =                                                  $
       cvtSisAdcToMonitorValue(G$_Sis.adc.MonitorP7V, hskp.MonitorP7V)
   engr.MonitorM7V =                                                  $
       cvtSisAdcToMonitorValue(G$_Sis.adc.MonitorM7V, hskp.MonitorM7V)
   engr.MonitorP13V =                                                 $
     cvtSisAdcToMonitorValue(G$_Sis.adc.MonitorP13V, hskp.MonitorP13V)
   engr.MonitorM13V =                                                 $
     cvtSisAdcToMonitorValue(G$_Sis.adc.MonitorM13V, hskp.MonitorM13V)
   engr.MonitorP19V =                                                 $
     cvtSisAdcToMonitorValue(G$_Sis.adc.MonitorP19V, hskp.MonitorP19V)
   engr.MonitorCurrentA =                                             $
                  cvtSisAdcToMonitorValue(G$_Sis.adc.MonitorCurrentA, $
                                          hskp.MonitorCurrentA)
   engr.MonitorCurrentB =                                             $
                  cvtSisAdcToMonitorValue(G$_Sis.adc.MonitorCurrentB, $
                                          hskp.MonitorCurrentB)

   ; Convert the ADC's for the temperatures.

   engr.TemperatureMotherBoard =                                      $
                          cvtSisAdcToDegC(hskp.TemperatureMotherBoard)
   engr.TemperatureAnalogBoard =                                      $
                          cvtSisAdcToDegC(hskp.TemperatureAnalogBoard)
   engr.TemperaturePostRegBoard =                                     $
                         cvtSisAdcToDegC(hskp.TemperaturePostRegBoard)
   engr.TemperatureLogicBoard =                                       $
                           cvtSisAdcToDegC(hskp.TemperatureLogicBoard)
   engr.TemperatureLvpsBoard =                                        $
                            cvtSisAdcToDegC(hskp.TemperatureLvpsBoard)
   engr.TemperatureHvpsBoard =                                        $
                            cvtSisAdcToDegC(hskp.TemperatureHvpsBoard)
   engr.TemperatureM1aBoard = cvtSisAdcToDegC(hskp.TemperatureM1aBoard)
   engr.TemperatureM2bBoard = cvtSisAdcToDegC(hskp.TemperatureM2bBoard)
   engr.TemperatureT12aBoard =                                        $
                            cvtSisAdcToDegC(hskp.TemperatureT12aBoard)
   engr.TemperatureT34aBoard =                                        $
                            cvtSisAdcToDegC(hskp.TemperatureT34aBoard)
   engr.TemperatureT56aBoard =                                        $
                            cvtSisAdcToDegC(hskp.TemperatureT56aBoard)
   engr.TemperatureT78aBoard =                                        $
                            cvtSisAdcToDegC(hskp.TemperatureT78aBoard)
   engr.TemperatureT12bBoard =                                        $
                            cvtSisAdcToDegC(hskp.TemperatureT12bBoard)
   engr.TemperatureT34bBoard =                                        $
                            cvtSisAdcToDegC(hskp.TemperatureT34bBoard)
   engr.TemperatureT56bBoard =                                        $
                            cvtSisAdcToDegC(hskp.TemperatureT56bBoard)
   engr.TemperatureT78bBoard =                                        $
                            cvtSisAdcToDegC(hskp.TemperatureT78bBoard)

   ; Convert the ADC's for the leakage currents.

   engr.LeakageCurrentT1a =                                           $
       cvtSisAdcToLeakageCurrent(G$_Sis.adc.PostDcT1a, hskp.PostDcT1a)
   engr.LeakageCurrentT2a =                                           $
       cvtSisAdcToLeakageCurrent(G$_Sis.adc.PostDcT2a, hskp.PostDcT2a)
   engr.LeakageCurrentT3a =                                           $
       cvtSisAdcToLeakageCurrent(G$_Sis.adc.PostDcT3a, hskp.PostDcT3a)
   engr.LeakageCurrentT4a =                                           $
       cvtSisAdcToLeakageCurrent(G$_Sis.adc.PostDcT4a, hskp.PostDcT4a)
   engr.LeakageCurrentT5a =                                           $
       cvtSisAdcToLeakageCurrent(G$_Sis.adc.PostDcT5a, hskp.PostDcT5a)
   engr.LeakageCurrentT6a =                                           $
       cvtSisAdcToLeakageCurrent(G$_Sis.adc.PostDcT6a, hskp.PostDcT6a)
   engr.LeakageCurrentT7a =                                           $
       cvtSisAdcToLeakageCurrent(G$_Sis.adc.PostDcT7a, hskp.PostDcT7a)
   engr.LeakageCurrentT8a =                                           $
       cvtSisAdcToLeakageCurrent(G$_Sis.adc.PostDcT8a, hskp.PostDcT8a)
   engr.LeakageCurrentT1b =                                           $
       cvtSisAdcToLeakageCurrent(G$_Sis.adc.PostDcT1b, hskp.PostDcT1b)
   engr.LeakageCurrentT2b =                                           $
       cvtSisAdcToLeakageCurrent(G$_Sis.adc.PostDcT2b, hskp.PostDcT2b)
   engr.LeakageCurrentT3b =                                           $
       cvtSisAdcToLeakageCurrent(G$_Sis.adc.PostDcT3b, hskp.PostDcT3b)
   engr.LeakageCurrentT4b =                                           $
       cvtSisAdcToLeakageCurrent(G$_Sis.adc.PostDcT4b, hskp.PostDcT4b)
   engr.LeakageCurrentT5b =                                           $
       cvtSisAdcToLeakageCurrent(G$_Sis.adc.PostDcT5b, hskp.PostDcT5b)
   engr.LeakageCurrentT6b =                                           $
       cvtSisAdcToLeakageCurrent(G$_Sis.adc.PostDcT6b, hskp.PostDcT6b)
   engr.LeakageCurrentT7b =                                           $
       cvtSisAdcToLeakageCurrent(G$_Sis.adc.PostDcT7b, hskp.PostDcT7b)
   engr.LeakageCurrentT8b =                                           $
       cvtSisAdcToLeakageCurrent(G$_Sis.adc.PostDcT8b, hskp.PostDcT8b)

   engr.CommandTableIndex = hskp.CommandTableIndex
   engr.StatusTelemetrySide = hskp.StatusTelemetrySide
   engr.StatusRefreshEnable = hskp.StatusRefreshEnable
   engr.StatusHeatAuto = hskp.StatusHeatAuto
   engr.StatusHeatLevel = hskp.StatusHeatLevel
   engr.QualityCycleNumber = hskp.QualityCycleNumber
   engr.QualityCommandTableIndex = hskp.QualityCommandTableIndex
   engr.QualityMonitorP4V = hskp.QualityMonitorP4V
   engr.QualityMonitorP5V = hskp.QualityMonitorP5V
   engr.QualityMonitorP7V = hskp.QualityMonitorP7V
   engr.QualityMonitorM7V = hskp.QualityMonitorM7V
   engr.QualityMonitorP13V = hskp.QualityMonitorP13V
   engr.QualityMonitorM13V = hskp.QualityMonitorM13V
   engr.QualityMonitorP19V = hskp.QualityMonitorP19V
   engr.QualityMonitorCurrentA = hskp.QualityMonitorCurrentA
   engr.QualityMonitorCurrentB = hskp.QualityMonitorCurrentB
   engr.QualityTemperatureMotherBoard =                               $
                                    hskp.QualityTemperatureMotherBoard
   engr.QualityTemperatureAnalogBoard =                               $
                                    hskp.QualityTemperatureAnalogBoard
   engr.QualityTemperaturePostRegBoard =                              $
                                   hskp.QualityTemperaturePostRegBoard
   engr.QualityTemperatureLogicBoard =                                $
                                     hskp.QualityTemperatureLogicBoard
   engr.QualityTemperatureLvpsBoard = hskp.QualityTemperatureLvpsBoard
   engr.QualityTemperatureHvpsBoard = hskp.QualityTemperatureHvpsBoard
   engr.QualityTemperatureM1aBoard = hskp.QualityTemperatureM1aBoard
   engr.QualityTemperatureM2bBoard = hskp.QualityTemperatureM2bBoard
   engr.QualityTemperatureT12aBoard = hskp.QualityTemperatureT12aBoard
   engr.QualityTemperatureT34aBoard = hskp.QualityTemperatureT34aBoard
   engr.QualityTemperatureT56aBoard = hskp.QualityTemperatureT56aBoard
   engr.QualityTemperatureT78aBoard = hskp.QualityTemperatureT78aBoard
   engr.QualityTemperatureT12bBoard = hskp.QualityTemperatureT12bBoard
   engr.QualityTemperatureT34bBoard = hskp.QualityTemperatureT34bBoard
   engr.QualityTemperatureT56bBoard = hskp.QualityTemperatureT56bBoard
   engr.QualityTemperatureT78bBoard = hskp.QualityTemperatureT78bBoard
   engr.QualityLeakageCurrentT1a = hskp.QualityPostDcT1a
   engr.QualityLeakageCurrentT2a = hskp.QualityPostDcT2a
   engr.QualityLeakageCurrentT3a = hskp.QualityPostDcT3a
   engr.QualityLeakageCurrentT4a = hskp.QualityPostDcT4a
   engr.QualityLeakageCurrentT5a = hskp.QualityPostDcT5a
   engr.QualityLeakageCurrentT6a = hskp.QualityPostDcT6a
   engr.QualityLeakageCurrentT7a = hskp.QualityPostDcT7a
   engr.QualityLeakageCurrentT8a = hskp.QualityPostDcT8a
   engr.QualityLeakageCurrentT1b = hskp.QualityPostDcT1b
   engr.QualityLeakageCurrentT2b = hskp.QualityPostDcT2b
   engr.QualityLeakageCurrentT3b = hskp.QualityPostDcT3b
   engr.QualityLeakageCurrentT4b = hskp.QualityPostDcT4b
   engr.QualityLeakageCurrentT5b = hskp.QualityPostDcT5b
   engr.QualityLeakageCurrentT6b = hskp.QualityPostDcT6b
   engr.QualityLeakageCurrentT7b = hskp.QualityPostDcT7b
   engr.QualityLeakageCurrentT8b = hskp.QualityPostDcT8b
   engr.QualityStatusTelemetrySide = hskp.QualityStatusTelemetrySide
   engr.QualityStatusRefreshEnable = hskp.QualityStatusRefreshEnable
   engr.QualityStatusHeatAuto = hskp.QualityStatusHeatAuto
   engr.QualityStatusHeatLevel = hskp.QualityStatusHeatLevel

   return, engr

end
