/* $Id: computeCrisDataBufferRates.c,v 1.1 1998/07/27 11:57:07 rgr Exp $ */

/* $RCSfile: computeCrisDataBufferRates.c,v $ */
/* $Author: rgr $ */
/* $Date: 1998/07/27 11:57:07 $ */
/* $Revision: 1.1 $ */

#include "hdfi.h"
#include "CrisConstants.h"

#include "cris/L1CrisLowPriorityRate.h"
#include "cris/L1_1CrisLowPriorityRate.h"

#include "cris/crisGetData/findCrisBufferType.h"

#define NBUF    NUM_CRIS_EVT_BUFFERS
#define NMNF    NUM_CRIS_MNFS_PER_CYCLE
#define OFFSET  CRIS_BUFFER_ID_OFFSET
#define Z1      CRIS_Z1_BUFFER
#define Z2      CRIS_Z2_BUFFER

void computeCrisDataBufferRates(struct L1CrisLowPriorityRate *lp,
                              struct L1_1CrisLowPriorityRate *engr)
{
   float64 EfficiencyInverse;
   float64 factor;
   float64 helivet;
   float64 hylivet;
       int i;
   float64 livetim;
   float64 nevproc;
   float64 nrebful;
       int type;

   livetim = (float64) (engr->livetim);
   if (livetim < 1.0e-6) livetim = 1.0e-6;
   helivet = (float64) (engr->helivet);
   if (helivet < 1.0e-6) helivet = 1.0e-6;
   hylivet = (float64) (engr->hylivet);
   if (hylivet < 1.0e-6) hylivet = 1.0e-6;

   nevproc = (float64) engr->nevproc;
   if (nevproc < 1.0 / ((float64) NMNF))
      nevproc =  1.0 / ((float64) NMNF);
   nrebful = (float64) engr->nrebful;

   EfficiencyInverse = (nevproc + nrebful) / nevproc;
 
   for (i=0; i<NBUF; i++) {
      type = findCrisBufferType(i + OFFSET);
      switch(type) {
         case Z1 :
              factor = EfficiencyInverse / hylivet;
              engr->DataBufferRate[i] =
                       (float32) (factor * lp->NumberEvents[i]);
              engr->QualityDataBufferRate[i] = 
                                           engr->QualityHylivet    |
                                           engr->QualityNevproc    |
                                           engr->QualityNrebful    |
                                           lp->QualityNumberEvents;
              break;
         case Z2 :
              factor = EfficiencyInverse / helivet;
              engr->DataBufferRate[i] =
                       (float32) (factor * lp->NumberEvents[i]);
              engr->QualityDataBufferRate[i] = 
                                           engr->QualityHelivet    |
                                           engr->QualityNevproc    |
                                           engr->QualityNrebful    |
                                           lp->QualityNumberEvents;
              break;
         default :
              factor = EfficiencyInverse / livetim;
              engr->DataBufferRate[i] =
                       (float32) (factor * lp->NumberEvents[i]);
              engr->QualityDataBufferRate[i] = 
                                           engr->QualityLivetim    |
                                           engr->QualityNevproc    |
                                           engr->QualityNrebful    |
                                           lp->QualityNumberEvents;
      }   
   }
}

#undef NBUF
#undef NMNF
#undef OFFSET
#undef Z1
#undef Z2
