/* $Id: computeCrisEventBufferRates.c,v 1.1 1998/07/27 11:58:05 rgr Exp $ */

/* $RCSfile: computeCrisEventBufferRates.c,v $ */
/* $Author: rgr $ */
/* $Date: 1998/07/27 11:58:05 $ */
/* $Revision: 1.1 $ */

#include "hdfi.h"
#include "CrisConstants.h"

#include "cris/L1CrisLowPriorityRate.h"
#include "cris/L1_1CrisLowPriorityRate.h"

#include "cris/crisGetData/findCrisBufferType.h"

#define NBUF    NUM_CRIS_EVT_BUFFERS
#define NMNF    NUM_CRIS_MNFS_PER_CYCLE
#define OFFSET  CRIS_BUFFER_ID_OFFSET
#define Z1      CRIS_Z1_BUFFER
#define Z2      CRIS_Z2_BUFFER

void computeCrisEventBufferRates(struct L1CrisLowPriorityRate *lp,
                               struct L1_1CrisLowPriorityRate *engr)
{
   float64 EfficiencyInverse;
   float64 factor;
   float64 helivet;
   float64 hylivet;
       int i;
   float64 livetim;
   float64 nevproc;
   float64 nrebful;
       int type;

   livetim = (float64) (engr->livetim);
   if (livetim < 1.0e-6) livetim = 1.0e-6;
   helivet = (float64) (engr->helivet);
   if (helivet < 1.0e-6) helivet = 1.0e-6;
   hylivet = (float64) (engr->hylivet);
   if (hylivet < 1.0e-6) hylivet = 1.0e-6;

   nevproc = (float64) engr->nevproc;
   if (nevproc < 1.0 / ((float64) NMNF))
      nevproc =  1.0 / ((float64) NMNF);
   nrebful = (float64) engr->nrebful;

   EfficiencyInverse = (nevproc + nrebful) / nevproc;
 
   for (i=0; i<NBUF; i++) {
      type = findCrisBufferType(i + OFFSET);
      switch(type) {
         case Z1 :
              factor = EfficiencyInverse / hylivet;
              engr->EventBufferRate[i] =
                       (float32) (factor * lp->EventBuffer[i]);
              engr->QualityEventBufferRate[i] = 
                                           engr->QualityHylivet      |
                                           engr->QualityNevproc      |
                                           engr->QualityNrebful      |
                                           lp->QualityEventBuffer[i];
              break;
         case Z2 :
              factor = EfficiencyInverse / helivet;
              engr->EventBufferRate[i] =
                       (float32) (factor * lp->EventBuffer[i]);
              engr->QualityEventBufferRate[i] = 
                                           engr->QualityHelivet      |
                                           engr->QualityNevproc      |
                                           engr->QualityNrebful      |
                                           lp->QualityEventBuffer[i];
              break;
         default :
              factor = EfficiencyInverse / livetim;
              engr->EventBufferRate[i] =
                       (float32) (factor * lp->EventBuffer[i]);
              engr->QualityEventBufferRate[i] = 
                                           engr->QualityLivetim      |
                                           engr->QualityNevproc      |
                                           engr->QualityNrebful      |
                                           lp->QualityEventBuffer[i];
      }   
   }
}

#undef NBUF
#undef NMNF
#undef OFFSET
#undef Z1
#undef Z2
