/* $Id: computeCrisSingleRates.c,v 1.1 1998/07/27 11:58:17 rgr Exp $ */

/* $RCSfile: computeCrisSingleRates.c,v $ */
/* $Author: rgr $ */
/* $Date: 1998/07/27 11:58:17 $ */
/* $Revision: 1.1 $ */

#include "hdfi.h"
#include "CrisConstants.h"

#include "cris/L1CrisLowPriorityRate.h"
#include "cris/L1_1CrisLowPriorityRate.h"


void computeCrisSingleRates(struct L1CrisLowPriorityRate *lp,
                          struct L1_1CrisLowPriorityRate *engr)
{
   float64 factor;
   float64 livetim;
   float64 nrtproc;
     uint8 quality;

   livetim = (float64) engr->livetim;
   if (livetim < 1.0e-6)
      livetim = 1.0e-6;
   nrtproc = (float64) engr->nrtproc;
   if (nrtproc < (1.0/NUM_CRIS_MNFS_PER_CYCLE))
      nrtproc = 1.0/NUM_CRIS_MNFS_PER_CYCLE;
   factor = ((float64) engr->nhdwrej) / (nrtproc * livetim);

   engr->stmco    = (float32) (factor * lp->stmco);
   engr->stmoff   = (float32) (factor * lp->stmoff);
   engr->z1ab     = (float32) (factor * lp->z1ab);
   engr->z2ab     = (float32) (factor * lp->z2ab);
   engr->z_gt_2ab = (float32) (factor * lp->z_gt_2ab);
   engr->z1cd     = (float32) (factor * lp->z1cd);
   engr->z2cd     = (float32) (factor * lp->z2cd);
   engr->z_gt_2cd = (float32) (factor * lp->z_gt_2cd);
   engr->hazard   = (float32) (factor * lp->hazard);
   engr->gh       = (float32) (factor * lp->gh);
   engr->mor      = (float32) (factor * lp->mor);
   engr->hor      = (float32) (factor * lp->hor);
   engr->adc2ab   = (float32) (factor * lp->adc2ab);
   engr->mnrgab   = (float32) (factor * lp->mnrgab);
   engr->adc2cd   = (float32) (factor * lp->adc2cd);
   engr->mnrgcd   = (float32) (factor * lp->mnrgcd);
   engr->e1a      = (float32) (factor * lp->e1a);
   engr->e1b      = (float32) (factor * lp->e1b);
   engr->e2ab     = (float32) (factor * lp->e2ab);
   engr->e3ab     = (float32) (factor * lp->e3ab);
   engr->e4ab     = (float32) (factor * lp->e4ab);
   engr->e5ab     = (float32) (factor * lp->e5ab);
   engr->e6ab     = (float32) (factor * lp->e6ab);
   engr->e7ab     = (float32) (factor * lp->e7ab);
   engr->e8ab     = (float32) (factor * lp->e8ab);
   engr->e9ab     = (float32) (factor * lp->e9ab);
   engr->g2ab     = (float32) (factor * lp->g2ab);
   engr->g3ab     = (float32) (factor * lp->g3ab);
   engr->g4ab     = (float32) (factor * lp->g4ab);
   engr->g5ab     = (float32) (factor * lp->g5ab);
   engr->g6ab     = (float32) (factor * lp->g6ab);
   engr->g7ab     = (float32) (factor * lp->g7ab);
   engr->e1c      = (float32) (factor * lp->e1c);
   engr->e1d      = (float32) (factor * lp->e1d);
   engr->e2cd     = (float32) (factor * lp->e2cd);
   engr->e3cd     = (float32) (factor * lp->e3cd);
   engr->e4cd     = (float32) (factor * lp->e4cd);
   engr->e5cd     = (float32) (factor * lp->e5cd);
   engr->e6cd     = (float32) (factor * lp->e6cd);
   engr->e7cd     = (float32) (factor * lp->e7cd);
   engr->e8cd     = (float32) (factor * lp->e8cd);
   engr->e9cd     = (float32) (factor * lp->e9cd);
   engr->g2cd     = (float32) (factor * lp->g2cd);
   engr->g3cd     = (float32) (factor * lp->g3cd);
   engr->g4cd     = (float32) (factor * lp->g4cd);
   engr->g5cd     = (float32) (factor * lp->g5cd);
   engr->g6cd     = (float32) (factor * lp->g6cd);
   engr->g7cd     = (float32) (factor * lp->g7cd);

   quality = engr->QualityNhdwrej | engr->QualityNrtproc
                                  | engr->QualityLivetim;

   engr->QualityStmco    = quality | lp->QualityStmco;
   engr->QualityStmoff   = quality | lp->QualityStmoff;
   engr->QualityZ1ab     = quality | lp->QualityZ1ab;
   engr->QualityZ2ab     = quality | lp->QualityZ2ab;
   engr->QualityZ_gt_2ab = quality | lp->QualityZ_gt_2ab;
   engr->QualityZ1cd     = quality | lp->QualityZ1cd;
   engr->QualityZ2cd     = quality | lp->QualityZ2cd;
   engr->QualityZ_gt_2cd = quality | lp->QualityZ_gt_2cd;
   engr->QualityHazard   = quality | lp->QualityHazard;
   engr->QualityGh       = quality | lp->QualityGh;
   engr->QualityMor      = quality | lp->QualityMor;
   engr->QualityHor      = quality | lp->QualityHor;
   engr->QualityAdc2ab   = quality | lp->QualityAdc2ab;
   engr->QualityMnrgab   = quality | lp->QualityMnrgab;
   engr->QualityAdc2cd   = quality | lp->QualityAdc2cd;
   engr->QualityMnrgcd   = quality | lp->QualityMnrgcd;
   engr->QualityE1a      = quality | lp->QualityE1a;
   engr->QualityE1b      = quality | lp->QualityE1b;
   engr->QualityE2ab     = quality | lp->QualityE2ab;
   engr->QualityE3ab     = quality | lp->QualityE3ab;
   engr->QualityE4ab     = quality | lp->QualityE4ab;
   engr->QualityE5ab     = quality | lp->QualityE5ab;
   engr->QualityE6ab     = quality | lp->QualityE6ab;
   engr->QualityE7ab     = quality | lp->QualityE7ab;
   engr->QualityE8ab     = quality | lp->QualityE8ab;
   engr->QualityE9ab     = quality | lp->QualityE9ab;
   engr->QualityG2ab     = quality | lp->QualityG2ab;
   engr->QualityG3ab     = quality | lp->QualityG3ab;
   engr->QualityG4ab     = quality | lp->QualityG4ab;
   engr->QualityG5ab     = quality | lp->QualityG5ab;
   engr->QualityG6ab     = quality | lp->QualityG6ab;
   engr->QualityG7ab     = quality | lp->QualityG7ab;
   engr->QualityE1c      = quality | lp->QualityE1c;
   engr->QualityE1d      = quality | lp->QualityE1d;
   engr->QualityE2cd     = quality | lp->QualityE2cd;
   engr->QualityE3cd     = quality | lp->QualityE3cd;
   engr->QualityE4cd     = quality | lp->QualityE4cd;
   engr->QualityE5cd     = quality | lp->QualityE5cd;
   engr->QualityE6cd     = quality | lp->QualityE6cd;
   engr->QualityE7cd     = quality | lp->QualityE7cd;
   engr->QualityE8cd     = quality | lp->QualityE8cd;
   engr->QualityE9cd     = quality | lp->QualityE9cd;
   engr->QualityG2cd     = quality | lp->QualityG2cd;
   engr->QualityG3cd     = quality | lp->QualityG3cd;
   engr->QualityG4cd     = quality | lp->QualityG4cd;
   engr->QualityG5cd     = quality | lp->QualityG5cd;
   engr->QualityG6cd     = quality | lp->QualityG6cd;
   engr->QualityG7cd     = quality | lp->QualityG7cd;
}
