/* $Id: cvtCrisAdcToDegC.c,v 1.1 1998/07/27 11:58:18 rgr Exp $ */

/* $RCSfile: cvtCrisAdcToDegC.c,v $ */
/* $Author: rgr $ */
/* $Date: 1998/07/27 11:58:18 $ */
/* $Revision: 1.1 $ */

#include <math.h>
#include "hdfi.h"

#include "cris/crisGetData/cvtCrisAdcToScaledVoltage.h"


float32 cvtCrisAdcToDegC(uint16 adc)
{
   static float64 CalibKOhm[] = {
                             884.6, 830.9, 780.8, 733.9, 690.2,
                             649.3, 611.0, 575.2, 541.7, 510.4,
                             481.0, 453.5, 427.7, 403.5, 380.9,
                             359.6, 339.6, 320.9, 303.3, 286.7,
                             271.2, 256.5, 242.8, 229.8, 217.6,
                             206.2, 195.4, 185.2, 175.6, 166.6,
                             158.0, 150.0, 142.4, 135.2, 128.5,
                             122.1, 116.0, 110.3, 104.9, 99.80, 94.98,
                             90.41, 86.09, 81.99, 78.11, 74.44,
                             70.95, 67.66, 64.53, 61.56, 58.75,
                             56.07, 53.54, 51.13, 48.84, 46.67,
                             44.50, 42.64, 40.77, 38.99, 37.30,
                             35.70, 34.17, 32.71, 31.32, 30.00,
                             28.74, 27.54, 26.40, 25.31, 24.27,
                             23.28, 22.33, 21.43, 20.57, 19.74,
                             18.96, 18.21, 17.49, 16.80, 16.15,
                             15.52, 14.92, 14.35, 13.80, 13.28,
                             12.77, 12.29, 11.83, 11.39, 10.97,
                             10.57, 10.18, 9.807, 9.450, 9.109,
                             8.781, 8.467, 8.166, 7.876, 7.599,
                             7.332, 7.076, 6.830, 6.594, 6.367,
                             6.148, 5.940, 5.738, 5.545, 5.359,
                             5.180, 5.007, 4.842, 4.682, 4.529,
                             4.381, 4.239, 4.102, 3.970, 3.843,
                             3.720, 3.602, 3.489, 3.379, 3.273,
                             3.172, 3.073, 2.979, 2.887, 2.799,
                             2.714, 2.632, 2.552, 2.476, 2.402,
                             2.331, 2.262, 2.195, 2.131, 2.059,
                             2.009, 1.950, 1.894, 1.840, 1.788,
                             1.737, 1.688, 1.640, 1.594, 1.550,
                             1.507, 1.465, 1.425, 1.386, 1.348,
                             1.311, 1.276, 1.241, 1.206, 1.176,
                             1.145, 1.114, 1.085, 1.057, 1.029,
                             1.002, .9763, .9511, .9287, .9030,
                             .8800, .8577, .8361, .8150, .7945,
                             .7748, .7555, .7369, .7188, .7012,
                             .6841, .6675, .6513, .6366, .6203,
                             .6055, .5911, .5771, .5635, .5502 };
   static float32 DegC[1024];
   static int NumCalibPts = 0;

   float64 CalibDegC0;
   float64 CalibDegC1;
   float64 DividerResistance;
   float64 fract0;
   float64 fract1;
       int i;
       int j;
       int jbeg;
   float64 LogCalibKOhm0;
   float64 LogCalibKOhm1;
   float64 LogR;
   float64 ReferenceVolt;
   float64 resistance[1024];
   float64 ScaledVolt;

   if (!NumCalibPts) {
      NumCalibPts = 191;

      ReferenceVolt = 5.0;
      DividerResistance = 30.1;
      for (i=0; i<1024; i++) {
         ScaledVolt = (float64) cvtCrisAdcToScaledVoltage((uint16) i);
         resistance[i] = (ScaledVolt / (ReferenceVolt - ScaledVolt))
                                                   * DividerResistance;
         if (resistance[i] > CalibKOhm[0]) 
            resistance[i] = CalibKOhm[0];
         if (resistance[i] < CalibKOhm[NumCalibPts - 1])
            resistance[i] = CalibKOhm[NumCalibPts - 1];
      }

      jbeg = 0;
      for (i=1; i<NumCalibPts; i++) {
         LogCalibKOhm0 = log10(CalibKOhm[i-1]);
         LogCalibKOhm1 = log10(CalibKOhm[i]);
         CalibDegC0 = ((float64) (i-1)) - 40.0;
         CalibDegC1 = ((float64) (i)) - 40.0;
         for (j=jbeg; j<1024; j++) {
            jbeg = j;
            if (resistance[j] < CalibKOhm[i]) break;
            LogR = log10(resistance[j]);
            fract0 = (LogR - LogCalibKOhm0) / 
                                       (LogCalibKOhm1 - LogCalibKOhm0);
            fract1 = (LogCalibKOhm1 - LogR) / 
                                       (LogCalibKOhm1 - LogCalibKOhm0);
            DegC[j] = (float32) (fract0*CalibDegC1 + fract1*CalibDegC0);
         }
      }

   }

   return DegC[adc];
}
