/* $Id: cvtCrisAdcToLeakageCurrent.c,v 1.1 1998/07/27 11:58:20 rgr Exp $ */

/* $RCSfile: cvtCrisAdcToLeakageCurrent.c,v $ */
/* $Author: rgr $ */
/* $Date: 1998/07/27 11:58:20 $ */
/* $Revision: 1.1 $ */

#include "hdfi.h"
#include "CrisAdc.h"
#include "CrisConstants.h"

#include "cris/crisGetData/cvtCrisAdcToScaledVoltage.h"
#include "cris/crisGetData/cvtCrisDacToControlVoltage.h"

#define E1A   CRIS_ADC_POSTDCE1A
#define E1B   CRIS_ADC_POSTDCE1B
#define E2AB  CRIS_ADC_POSTDCE2AB
#define E3AB  CRIS_ADC_POSTDCE3AB
#define E4AB  CRIS_ADC_POSTDCE4AB
#define E5AB  CRIS_ADC_POSTDCE5AB
#define E6AB  CRIS_ADC_POSTDCE6AB
#define E7AB  CRIS_ADC_POSTDCE7AB
#define E8AB  CRIS_ADC_POSTDCE8AB
#define E9AB  CRIS_ADC_POSTDCE9AB
#define G2AB  CRIS_ADC_POSTDCG2AB
#define G3AB  CRIS_ADC_POSTDCG3AB
#define G4AB  CRIS_ADC_POSTDCG4AB
#define G5AB  CRIS_ADC_POSTDCG5AB
#define G6AB  CRIS_ADC_POSTDCG6AB
#define G7AB  CRIS_ADC_POSTDCG7AB
#define E1C   CRIS_ADC_POSTDCE1C
#define E1D   CRIS_ADC_POSTDCE1D
#define E2CD  CRIS_ADC_POSTDCE2CD
#define E3CD  CRIS_ADC_POSTDCE3CD
#define E4CD  CRIS_ADC_POSTDCE4CD
#define E5CD  CRIS_ADC_POSTDCE5CD
#define E6CD  CRIS_ADC_POSTDCE6CD
#define E7CD  CRIS_ADC_POSTDCE7CD
#define E8CD  CRIS_ADC_POSTDCE8CD
#define E9CD  CRIS_ADC_POSTDCE9CD
#define G2CD  CRIS_ADC_POSTDCG2CD
#define G3CD  CRIS_ADC_POSTDCG3CD
#define G4CD  CRIS_ADC_POSTDCG4CD
#define G5CD  CRIS_ADC_POSTDCG5CD
#define G6CD  CRIS_ADC_POSTDCG6CD
#define G7CD  CRIS_ADC_POSTDCG7CD

float32 cvtCrisAdcToLeakageCurrent(int AdcNumber,
                                uint16 adc,
                                 uint8 dac)
{
   static float64 slope[NUM_CRIS_ADC];
   static float64 offset[NUM_CRIS_ADC];
   static float64 CtlVolt[NUM_CRIS_ADC];
   static float64 ScaleFactor[NUM_CRIS_ADC];
   static int first = 1;

   float64 ControlVoltage;
       int i;
   float64 PostdcBaseline; 
   float64 Rf308, Rpostin308;
   float64 Rf309, Rpostin309;
   float64 Rf310, Rpostin310;
   float64 Rf311, Rpostin311;
   float64 Rf312, Rpostin312;
   float64 ScaledVoltage;

   if (first) {

      first = 0;
      for (i=0; i<NUM_CRIS_ADC; i++) {
         slope[i]       = 0.0;
         offset[i]      = 0.0;
         CtlVolt[i]     = 0.0;
         ScaleFactor[i] = 0.0;
      }

      slope[E1A ]=0.0923;  offset[E1A ]=-0.4604;  CtlVolt[E1A ]= 6.0;
      slope[E1B ]=0.0922;  offset[E1B ]=-0.4507;  CtlVolt[E1B ]= 6.0;
      slope[E1C ]=0.0921;  offset[E1C ]=-0.4659;  CtlVolt[E1C ]= 6.0;
      slope[E1D ]=0.0926;  offset[E1D ]=-0.4656;  CtlVolt[E1D ]= 6.0;
      slope[E2AB]=0.0917;  offset[E2AB]=-0.4535;  CtlVolt[E2AB]=12.0;
      slope[E2CD]=0.0923;  offset[E2CD]=-0.4664;  CtlVolt[E2CD]=12.0;
      slope[E3AB]=0.2325;  offset[E3AB]=-0.5217;  CtlVolt[E3AB]=12.0;
      slope[E3CD]=0.2311;  offset[E3CD]=-0.5213;  CtlVolt[E3CD]=12.0;
      slope[E4AB]=0.2343;  offset[E4AB]=-0.5195;  CtlVolt[E4AB]=12.0;
      slope[E4CD]=0.2342;  offset[E4CD]=-0.5319;  CtlVolt[E4CD]=12.0;
      slope[E5AB]=0.2349;  offset[E5AB]=-0.5252;  CtlVolt[E5AB]=12.0;
      slope[E5CD]=0.2331;  offset[E5CD]=-0.5313;  CtlVolt[E5CD]=12.0;
      slope[E6AB]=0.2335;  offset[E6AB]=-0.5294;  CtlVolt[E6AB]=12.0;
      slope[E6CD]=0.2341;  offset[E6CD]=-0.5400;  CtlVolt[E6CD]=12.0;
      slope[E7AB]=0.2334;  offset[E7AB]=-0.5381;  CtlVolt[E7AB]=12.0;
      slope[E7CD]=0.2350;  offset[E7CD]=-0.5166;  CtlVolt[E7CD]=12.0;
      slope[E8AB]=0.2351;  offset[E8AB]=-0.5251;  CtlVolt[E8AB]=12.0;
      slope[E8CD]=0.2342;  offset[E8CD]=-0.5156;  CtlVolt[E8CD]=12.0;
      slope[E9AB]=5.2911;  offset[E9AB]= 1.0582;  CtlVolt[E9AB]= 0.0;
      slope[E9CD]=5.2911;  offset[E9CD]= 1.0692;  CtlVolt[E9CD]= 0.0;
      slope[G2AB]=5.2911;  offset[G2AB]= 0.8908;  CtlVolt[G2AB]= 0.0;
      slope[G2CD]=5.2911;  offset[G2CD]= 0.8427;  CtlVolt[G2CD]= 0.0;
      slope[G3AB]=5.2911;  offset[G3AB]= 2.2739;  CtlVolt[G3AB]= 0.0;
      slope[G3CD]=5.2911;  offset[G3CD]= 2.3594;  CtlVolt[G3CD]= 0.0;
      slope[G4AB]=5.2911;  offset[G4AB]= 2.4014;  CtlVolt[G4AB]= 0.0;
      slope[G4CD]=5.2911;  offset[G4CD]= 2.4213;  CtlVolt[G4CD]= 0.0;
      slope[G5AB]=5.2911;  offset[G5AB]= 2.3127;  CtlVolt[G5AB]= 0.0;
      slope[G5CD]=5.2911;  offset[G5CD]= 2.3309;  CtlVolt[G5CD]= 0.0;
      slope[G6AB]=5.2911;  offset[G6AB]= 2.2971;  CtlVolt[G6AB]= 0.0;
      slope[G6CD]=5.2911;  offset[G6CD]= 2.3396;  CtlVolt[G6CD]= 0.0;
      slope[G7AB]=5.2911;  offset[G7AB]= 2.3363;  CtlVolt[G7AB]= 0.0;
      slope[G7CD]=5.2911;  offset[G7CD]= 2.2620;  CtlVolt[G7CD]= 0.0;

      Rf308 =  2000.0;   Rpostin308 = 2550.0;
      Rf309 =  1330.0;   Rpostin309 = 2550.0;
      Rf310 = 29400.0;   Rpostin310 = 2490.0;
      Rf311 = 29400.0;   Rpostin311 = 2490.0;
      Rf312 = 29400.0;   Rpostin312 = 2490.0;

      ScaleFactor[E1A ] = ((Rpostin308 / Rf308) / 20300.0) * (-1.0e6);
      ScaleFactor[E1B ] = ((Rpostin308 / Rf308) / 20300.0) * (-1.0e6);
      ScaleFactor[E1C ] = ((Rpostin308 / Rf308) / 20300.0) * (-1.0e6);
      ScaleFactor[E1D ] = ((Rpostin308 / Rf308) / 20300.0) * (-1.0e6);
      ScaleFactor[E2AB] = ((Rpostin308 / Rf308) / 20300.0) * (-1.0e6);
      ScaleFactor[E2CD] = ((Rpostin308 / Rf308) / 20300.0) * (-1.0e6);
      ScaleFactor[E3AB] = ((Rpostin309 / Rf309) / 20300.0) * (-1.0e6);
      ScaleFactor[E3CD] = ((Rpostin309 / Rf309) / 20300.0) * (-1.0e6);
      ScaleFactor[E4AB] = ((Rpostin309 / Rf309) / 20300.0) * (-1.0e6);
      ScaleFactor[E4CD] = ((Rpostin309 / Rf309) / 20300.0) * (-1.0e6);
      ScaleFactor[E5AB] = ((Rpostin309 / Rf309) / 20300.0) * (-1.0e6);
      ScaleFactor[E5CD] = ((Rpostin309 / Rf309) / 20300.0) * (-1.0e6);
      ScaleFactor[E6AB] = ((Rpostin309 / Rf309) / 20300.0) * (-1.0e6);
      ScaleFactor[E6CD] = ((Rpostin309 / Rf309) / 20300.0) * (-1.0e6);
      ScaleFactor[E7AB] = ((Rpostin309 / Rf309) / 20300.0) * (-1.0e6);
      ScaleFactor[E7CD] = ((Rpostin309 / Rf309) / 20300.0) * (-1.0e6);
      ScaleFactor[E8AB] = ((Rpostin309 / Rf309) / 20300.0) * (-1.0e6);
      ScaleFactor[E8CD] = ((Rpostin309 / Rf309) / 20300.0) * (-1.0e6);
      ScaleFactor[E9AB] = ((Rpostin310 / Rf310) / 20300.0) * (-1.0e6);
      ScaleFactor[E9CD] = ((Rpostin310 / Rf310) / 20300.0) * (-1.0e6);
      ScaleFactor[G2AB] = ((Rpostin311 / Rf311) / 20300.0) * (-1.0e6);
      ScaleFactor[G2CD] = ((Rpostin311 / Rf311) / 20300.0) * (-1.0e6);
      ScaleFactor[G3AB] = ((Rpostin312 / Rf312) / 20300.0) * (-1.0e6);
      ScaleFactor[G3CD] = ((Rpostin312 / Rf312) / 20300.0) * (-1.0e6);
      ScaleFactor[G4AB] = ((Rpostin312 / Rf312) / 20300.0) * (-1.0e6);
      ScaleFactor[G4CD] = ((Rpostin312 / Rf312) / 20300.0) * (-1.0e6);
      ScaleFactor[G5AB] = ((Rpostin312 / Rf312) / 20300.0) * (-1.0e6);
      ScaleFactor[G5CD] = ((Rpostin312 / Rf312) / 20300.0) * (-1.0e6);
      ScaleFactor[G6AB] = ((Rpostin312 / Rf312) / 20300.0) * (-1.0e6);
      ScaleFactor[G6CD] = ((Rpostin312 / Rf312) / 20300.0) * (-1.0e6);
      ScaleFactor[G7AB] = ((Rpostin312 / Rf312) / 20300.0) * (-1.0e6);
      ScaleFactor[G7CD] = ((Rpostin312 / Rf312) / 20300.0) * (-1.0e6);
   }

   if (dac == CRIS_UNDEFINED_8)
      ControlVoltage = CtlVolt[AdcNumber];
   else
      ControlVoltage = (float64) cvtCrisDacToControlVoltage(dac);

   ScaledVoltage = (float64) cvtCrisAdcToScaledVoltage(adc);
   PostdcBaseline = (ControlVoltage * slope[AdcNumber]) + 
                                                     offset[AdcNumber];
   return (float32) ((ScaledVoltage - PostdcBaseline)
                                             * ScaleFactor[AdcNumber]);
}

#undef E1A
#undef E1B
#undef E2AB
#undef E3AB
#undef E4AB
#undef E5AB
#undef E6AB
#undef E7AB
#undef E8AB
#undef E9AB
#undef G2AB
#undef G3AB
#undef G4AB
#undef G5AB
#undef G6AB
#undef G7AB
#undef E1C
#undef E1D
#undef E2CD
#undef E3CD
#undef E4CD
#undef E5CD
#undef E6CD
#undef E7CD
#undef E8CD
#undef E9CD
#undef G2CD
#undef G3CD
#undef G4CD
#undef G5CD
#undef G6CD
#undef G7CD
