#ifndef GETGROUPSUMMARYS_CE
   #define GETGROUPSUMMARYS_CE

   /* $Id: getGroupSummarys_ce.c,v 1.1 1998/07/27 11:59:46 rgr Exp $ */

   /* $RCSfile: getGroupSummarys_ce.c,v $ */
   /* $Author: rgr $ */
   /* $Date: 1998/07/27 11:59:46 $ */
   /* $Revision: 1.1 $ */


   #include <stdlib.h>
   #include <string.h>

   #include "hdfi.h"
   #include "CrisConstants.h"
   
   #include "cris/L1CrisSummary.h"
   #include "cris/L1_1CrisSummary.h"

   #include "ace/AceNaN.h"
   #include "crisGetData/getGroupSummarys_c.h"

   #define NHSKP  NUM_CRIS_HSKP_BYTES

   struct L1_1CrisSummary *getGroupSummarys_ce(uint32 sec1996_0,
                                               uint32 sec1996_1,
                                                  int autoFreeFlag)
   {
      static struct L1_1CrisSummary *allocatedMemory = NULL;

      struct L1_1CrisSummary *engr;
                      size_t nrec;
      struct L1_1CrisSummary *pointerEngr;
        struct L1CrisSummary *pointerSum;
        struct L1CrisSummary *sum;

      /* Do the automatic deallocation of memory.  When free is    */
      /* called with the address of a previously allocated memory  */
      /* block, free deallocates the memory block.  If the address */
      /* is NULL, free does nothing.                               */

      free(allocatedMemory);


      /* Find the number of structures and allocate and zero the */
      /* memory for them.                                        */

      pointerSum = getGroupSummarys_c(sec1996_0, sec1996_1, 0);
      sum = pointerSum;
      nrec = 0;
      while (sum->Second1996) {
         nrec++;
         sum++;
      }
      pointerEngr = calloc(nrec+1, sizeof(struct L1_1CrisSummary));



      /* Build an L1_1CrisSummary structure for each L1CrisSummary */
      /* structure present.                                        */

      sum = pointerSum;
      engr = pointerEngr;
      while (sum->Second1996) {
         engr->ClockMinorFrame = sum->ClockMinorFrame;
         engr->Second1996 = sum->Second1996;
         engr->microsecond = sum->microsecond;
         engr->FormatId = sum->FormatId;
         engr->MajorFrameCount = sum->MajorFrameCount;
         engr->MinorFrameCount = sum->MinorFrameCount;
         engr->quality = sum->quality;

         /* Convert the ADC's for voltage, currents, and */
         /* temperatures.                                */

         if (sum->MainBusVoltage != 0xff) 
            engr->MainBusVoltage =
                 (float32) (0.15054 * ((float64) sum->MainBusVoltage));
         else
            engr->MainBusVoltage = AceNaN();

         if (sum->CrisCurrent != 0xff) 
            engr->CrisCurrent =
                   (float32) (0.005602 * ((float64) sum->CrisCurrent));
         else
            engr->CrisCurrent = AceNaN();

         if (sum->CrisInternalTemperature1 != 0xff) 
            engr->CrisInternalTemperature1 = (float32) (-0.62745 *
                    ((float64) sum->CrisInternalTemperature1) + 100.0);
         else
            engr->CrisInternalTemperature1 = AceNaN(); 

         if (sum->CrisInternalTemperature2 != 0xff) 
            engr->CrisInternalTemperature2 = (float32) (-0.62745 *
                    ((float64) sum->CrisInternalTemperature2) + 100.0);
         else
            engr->CrisInternalTemperature2 = AceNaN(); 

         if (sum->CrisInterfaceTemperature != 0xff) 
            engr->CrisInterfaceTemperature = (float32) (-0.62745 *
                    ((float64) sum->CrisInterfaceTemperature) + 100.0);
         else
            engr->CrisInterfaceTemperature = AceNaN(); 

         /* Copy the telemetry data. */

         memcpy(engr->CrisHskp, sum->CrisHskp, NHSKP);

         engr++;
         sum++;
      }
      free(pointerSum);


      /* Set the variable that controls the automatic deallocation */
      /* of the memory allocated.  If the user wants automatic     */
      /* deallocation of memory, set the variable equal to address */
      /* of the allocated memory; otherwise, set to NULL.          */

      allocatedMemory = autoFreeFlag ? pointerEngr : NULL;

      return pointerEngr;
   }

   #undef NHSKP

#endif
