#ifndef GETGROUPSUBSETS_SE
   #define GETGROUPSUBSETS_SE

   /* $Id: getGroupSubsets_se.c,v 1.1 1998/07/27 12:34:37 rgr Exp $ */

   /* $RCSfile: getGroupSubsets_se.c,v $ */
   /* $Author: rgr $ */
   /* $Date: 1998/07/27 12:34:37 $ */
   /* $Revision: 1.1 $ */


   #include <stdlib.h>
   #include <string.h>

   #include "hdfi.h"
   #include "SisConstants.h"
   
   #include "sis/L1SisSubset.h"
   #include "sis/L1_1SisSubset.h"

   #include "ace/AceNaN.h"
   #include "sisGetData/getGroupSubsets_s.h"

   #define NDATA  NUM_SIS_TELEMETRY_BYTES

   struct L1_1SisSubset *getGroupSubsets_se(uint32 sec1996_0,
                                            uint32 sec1996_1,
                                               int autoFreeFlag)
   {
      static struct L1_1SisSubset *allocatedMemory = NULL;

      struct L1_1SisSubset *engr;
                    size_t nrec;
      struct L1_1SisSubset *pointerEngr;
        struct L1SisSubset *pointerSub;
        struct L1SisSubset *sub;

      /* Do the automatic deallocation of memory.  When free is    */
      /* called with the address of a previously allocated memory  */
      /* block, free deallocates the memory block.  If the address */
      /* is NULL, free does nothing.                               */

      free(allocatedMemory);


      /* Find the number of structures and allocate and zero the */
      /* memory for them.                                        */

      pointerSub = getGroupSubsets_s(sec1996_0, sec1996_1, 0);
      sub = pointerSub;
      nrec = 0;
      while (sub->Second1996) {
         nrec++;
         sub++;
      }
      pointerEngr = calloc(nrec+1, sizeof(struct L1_1SisSubset));



      /* Build an L1_1SisSubset structure for each L1SisSubset */
      /* structure present.                                    */

      sub = pointerSub;
      engr = pointerEngr;
      while (sub->Second1996) {
         engr->ClockMinorFrame = sub->ClockMinorFrame;
         engr->Second1996 = sub->Second1996;
         engr->microsecond = sub->microsecond;
         engr->FormatId = sub->FormatId;
         engr->MajorFrameCount = sub->MajorFrameCount;
         engr->MinorFrameCount = sub->MinorFrameCount;
         engr->quality = sub->quality;

         /* Convert the ADC's for voltage, currents, and */
         /* temperatures.                                */

         if (sub->MainBusVoltage != 0xff) 
            engr->MainBusVoltage =
                 (float32) (0.15054 * ((float64) sub->MainBusVoltage));
         else
            engr->MainBusVoltage = AceNaN();

         if (sub->SisCurrent != 0xff) 
            engr->SisCurrent =
                    (float32) (0.005942 * ((float64) sub->SisCurrent));
         else
            engr->SisCurrent = AceNaN();

         if (sub->SisInternalTemperature1 != 0xff) 
            engr->SisInternalTemperature1 = (float32) (-0.62745 *
                     ((float64) sub->SisInternalTemperature1) + 100.0);
         else
            engr->SisInternalTemperature1 = AceNaN(); 

         if (sub->SisInternalTemperature2 != 0xff) 
            engr->SisInternalTemperature2 = (float32) (-0.62745 *
                     ((float64) sub->SisInternalTemperature2) + 100.0);
         else
            engr->SisInternalTemperature2 = AceNaN(); 

         if (sub->SisInterfaceTemperature != 0xff) 
            engr->SisInterfaceTemperature = (float32) (-0.62745 *
                     ((float64) sub->SisInterfaceTemperature) + 100.0);
         else
            engr->SisInterfaceTemperature = AceNaN(); 

         engr->SisCoverTelltale = sub->SisCoverTelltale;

         /* Copy the telemetry data. */

         memcpy(engr->SisData, sub->SisData, NDATA);

         engr++;
         sub++;
      }
      free(pointerSub);


      /* Set the variable that controls the automatic deallocation */
      /* of the memory allocated.  If the user wants automatic     */
      /* deallocation of memory, set the variable equal to address */
      /* of the allocated memory; otherwise, set to NULL.          */

      allocatedMemory = autoFreeFlag ? pointerEngr : NULL;

      return pointerEngr;
   }

   #undef NHSKP

#endif
