#ifndef GETGROUPSUMMARYS_SE
   #define GETGROUPSUMMARYS_SE

   /* $Id: getGroupSummarys_se.c,v 1.1 1998/07/27 12:34:38 rgr Exp $ */

   /* $RCSfile: getGroupSummarys_se.c,v $ */
   /* $Author: rgr $ */
   /* $Date: 1998/07/27 12:34:38 $ */
   /* $Revision: 1.1 $ */


   #include <stdlib.h>
   #include <string.h>

   #include "hdfi.h"
   #include "SisConstants.h"
   
   #include "sis/L1SisSummary.h"
   #include "sis/L1_1SisSummary.h"

   #include "ace/AceNaN.h"
   #include "sisGetData/getGroupSummarys_s.h"

   #define NHSKP  NUM_SIS_HSKP_BYTES

   struct L1_1SisSummary *getGroupSummarys_se(uint32 sec1996_0,
                                              uint32 sec1996_1,
                                                 int autoFreeFlag)
   {
      static struct L1_1SisSummary *allocatedMemory = NULL;

      struct L1_1SisSummary *engr;
                     size_t nrec;
      struct L1_1SisSummary *pointerEngr;
        struct L1SisSummary *pointerSum;
        struct L1SisSummary *sum;

      /* Do the automatic deallocation of memory.  When free is    */
      /* called with the address of a previously allocated memory  */
      /* block, free deallocates the memory block.  If the address */
      /* is NULL, free does nothing.                               */

      free(allocatedMemory);


      /* Find the number of structures and allocate and zero the */
      /* memory for them.                                        */

      pointerSum = getGroupSummarys_s(sec1996_0, sec1996_1, 0);
      sum = pointerSum;
      nrec = 0;
      while (sum->Second1996) {
         nrec++;
         sum++;
      }
      pointerEngr = calloc(nrec+1, sizeof(struct L1_1SisSummary));



      /* Build an L1_1SisSummary structure for each L1SisSummary */
      /* structure present.                                      */

      sum = pointerSum;
      engr = pointerEngr;
      while (sum->Second1996) {
         engr->ClockMinorFrame = sum->ClockMinorFrame;
         engr->Second1996 = sum->Second1996;
         engr->microsecond = sum->microsecond;
         engr->FormatId = sum->FormatId;
         engr->MajorFrameCount = sum->MajorFrameCount;
         engr->MinorFrameCount = sum->MinorFrameCount;
         engr->quality = sum->quality;

         /* Convert the ADC's for voltage, currents, and */
         /* temperatures.                                */

         if (sum->MainBusVoltage != 0xff) 
            engr->MainBusVoltage =
                 (float32) (0.15054 * ((float64) sum->MainBusVoltage));
         else
            engr->MainBusVoltage = AceNaN();

         if (sum->SisCurrent != 0xff) 
            engr->SisCurrent =
                    (float32) (0.005942 * ((float64) sum->SisCurrent));
         else
            engr->SisCurrent = AceNaN();

         if (sum->SisInternalTemperature1 != 0xff) 
            engr->SisInternalTemperature1 = (float32) (-0.62745 *
                     ((float64) sum->SisInternalTemperature1) + 100.0);
         else
            engr->SisInternalTemperature1 = AceNaN(); 

         if (sum->SisInternalTemperature2 != 0xff) 
            engr->SisInternalTemperature2 = (float32) (-0.62745 *
                     ((float64) sum->SisInternalTemperature2) + 100.0);
         else
            engr->SisInternalTemperature2 = AceNaN(); 

         if (sum->SisInterfaceTemperature != 0xff) 
            engr->SisInterfaceTemperature = (float32) (-0.62745 *
                     ((float64) sum->SisInterfaceTemperature) + 100.0);
         else
            engr->SisInterfaceTemperature = AceNaN(); 

         engr->SisCoverTelltale = sum->SisCoverTelltale;

         /* Copy the telemetry data. */

         memcpy(engr->SisHskp, sum->SisHskp, NHSKP);

         engr++;
         sum++;
      }
      free(pointerSum);


      /* Set the variable that controls the automatic deallocation */
      /* of the memory allocated.  If the user wants automatic     */
      /* deallocation of memory, set the variable equal to address */
      /* of the allocated memory; otherwise, set to NULL.          */

      allocatedMemory = autoFreeFlag ? pointerEngr : NULL;

      return pointerEngr;
   }

   #undef NHSKP

#endif
