/* $Id: uncompressSisValue.c,v 1.1 1998/07/27 12:18:45 rgr Exp $ */

/* $RCSfile: uncompressSisValue.c,v $ */
/* $Author: rgr $ */
/* $Date: 1998/07/27 12:18:45 $ */
/* $Revision: 1.1 $ */

/* UncompressSisValue                                                 */
/*                                                                    */
/* This function uncompresses the counters that are used to calculate */
/* rates for the SIS instrument.  The counter values are always       */
/* non-negative integers.  For counter values less than or equal to   */
/* 4096, the compressed value and the uncompressed are identical.     */
/* For values greater than 4096, the values are stored as an 11 bit   */
/* fraction with an implicit one and a 4-bit exponent with bias       */
/* of 1.                                                              */
/*                                                                    */
/* When uncompressing the values greater than 4096, this function     */
/* forms a thirteen bit fraction by changing the implicit one into    */
/* an explicit one, shifting the fraction to the left by one, and     */
/* setting the least significant bit to one.  To compensate for the   */
/* the left shift of the fraction, the bias is increased by one.      */
/*                                                                    */
/* Arguments                                                          */
/*    val = compressed SIS counter value - input                      */


#include "hdfi.h"

float32 uncompressSisValue(uint16 val)
{
   uint32 value;
   uint32 exponent;

   value = (uint32) val;
   if (value < 4096) return (float32) value;

   exponent = (value >> 11) - 2;
   value = ((value & 0x000007FF) << 1) | 0x00001001;
   value <<= exponent;
   return ((float32) value) - 0.5;
}
