/* $Id: buildSegmentDictionary.c,v 1.1 1998/05/04 17:53:49 rgr Exp $ */

/* $RCSfile: buildSegmentDictionary.c,v $ */
/* $Author: rgr $ */
/* $Date: 1998/05/04 17:53:49 $ */
/* $Revision: 1.1 $ */


#ifndef BUILD_SEGMENT_DICTIONARY_C
   #define BUILD_SEGMENT_DICTIONARY_C

   /* This function builds the segment dictionary from the           */
   /* information contained in the template file.  Each segment in   */
   /* the dictionary is defined by the four fields:  name, variable, */
   /* format, and compressed name.                                   */
   /*                                                                */
   /* The template file that defines the dictionary contains one     */
   /* line for each entry to be put into the dictionary.  That line  */
   /* contains the name, variable, and format fields enclosed within */
   /* the segment delimiters.  The compressed name field is derived  */
   /* from the name field by replacing any macro placeholders in the */
   /* name field with blanks and then removing all blanks from the   */
   /* name.                                                          */
   /*                                                                */
   /*                                                                */
   /*  Arguments                                                     */
   /*     index0 = first dictionary line of the template-(input)     */
   /*     index1 = last dictionary line of the template-(input)      */
   /*     line = array containing the template-(input)               */
   /*     segmentDelimiter = segment delimiters used in the          */
   /*                        template-(input)                        */
   /*     macroDelimiter = macro delimiters used in the              */
   /*                      segments-(input)                          */
   /*     dictName = full name of each dictionary entry-(output)     */
   /*     dictVariable = segment variables of each dictionary        */
   /*                    entry-(output)                              */
   /*     dictFormat = format field of each dictionary               */
   /*                  entry-(output)                                */
   /*     dictNameCompressed = compressed name of each dictionary    */
   /*                          entry-(output)                        */

   #include <string.h>

   #include "compressDumpSegment.c"


   void buildSegmentDictionary(int index0,
                               int index1,
                               char line[][256],
                               char *segmentDelimiter,
                               char *macroDelimiter,
                               char dictName[][128],
                               char dictVariable[][128],
                               char dictFormat[][128], 
                               char dictNameCompressed[][128])
   {

       int i;
       int ii;
      char *mark0;
      char *mark1;
      char tmp[256];

      ii = 0;
      for (i=index0; i<=index1; i++) {
         strcpy(tmp, line[i]);

         mark0 = strchr(tmp + 0, segmentDelimiter[0]);
         mark1 = strchr(mark0, segmentDelimiter[1]);
         *mark1 = '\0';
         strcpy(dictName[ii], mark0 + 1);
         compressDumpSegment(dictNameCompressed[ii],
                             dictName[ii],
                             macroDelimiter);

         mark0 = strchr(mark1 +1, segmentDelimiter[0]);
         mark1 = strchr(mark0, segmentDelimiter[1]);
         *mark1 = '\0';
         strcpy(dictVariable[ii], mark0 + 1);

         mark0 = strchr(mark1 + 1, segmentDelimiter[0]);
         mark1 = strchr( mark0, segmentDelimiter[1]);
         *mark1 = '\0';
         strcpy(dictFormat[ii], mark0 + 1);

         ii++;
      }
   }

#endif
